# !/bin/sh
# ==============================================================================
#                   GONICUS Terminal Image Creation Script
#      Version 1.0  (C) 2001, 2002 Cajus Pollmeier <pollmeier@gonicus.de>
#                                  and Jrg Platte <jplatte@jako.ping.de>
# ==============================================================================
set -e


## Initialization --------------------------------------------------------------
#
# Be sure to get all messages in english
LC_ALL=C

# Check for DISPLAY and warn in case of konsole. Better use xterm...
if [ -n "$DISPLAY" ]; then
	echo "Seems like you're running the script under X11.  Just informing you, that"
	echo "KDE's konsole application is blacking out during the installation and you"
	echo "wouldn't see whats going on. An ordinary xterm has no problems with that."
	echo -e "\nPress Ctrl+c to abort, Enter to continue."
	read
fi


# Like the name suggests...
function usage(){
	echo "imaGen v1.0 - Image Creation Script - (C) 2001, 2002 GONICUS GmbH"
	echo "written by Jrg Platte <jplatte@jako.ping.de> and"
	echo "           Cajus Pollmeier <pollmeier@gonicus.de>"
	echo
	echo "Usage: `basename $0` options ..."
	echo " List of options:"
	echo " --all       Performs a complete build of the terminal image. This"
	echo "             includes the create, strip, tar and cramfs stages."
	echo " --cfg file  Specifies another configuration file than the default"
	echo "             in \"./config/create_image.conf\"."
	echo " --clean     Removes the complete build and image structure."
	echo " --cramfs    Create the cramfs image."
	echo " --create    Create the base debian image."
	echo " --strip     Strip the base debian image."
	echo " --tar       Create a tar'red image."
}


# Dummy placeholder
function post_install(){
	echo "Post-install is not defined."
}

function post_strip() {
	echo "Post-strip is not defined."
}


# check command line parameters
if [ $# = 0 ]; then
	usage
	exit 0
fi

# Check command line parameters
while [ $# != 0 ] ; do
	case "$1" in
		--clean)
			CLEAN=1
			;;

		--all)	
			CREATE=1
			STRIP=1
			TAR=1
			CRAMFS=1
			;;
			
		--cfg)
			shift
			[ "X$1" != "X" ] && CFG_FILE=$1
			;;
		
		--strip)
			STRIP=1
			;;
	
		--tar)
			TAR=1
			;;

		--cramfs)
			CRAMFS=1
			;;

		--create)
			CREATE=1
			;;

		*)	usage
			exit 1
			;;
	esac

	# Check the next one
	shift
done


## Preamble / Checks -----------------------------------------------------------
#

# Any action?
if [ "$CREATE" -o "$STRIP" -o "$TAR" -o "$CRAMFS" -o "$CLEAN" ]; then
	echo "Some actions to perform. Perfect."
else
	usage
	echo -e "\nError: You need to specify an action to perform."
	exit 1
fi


# Include setup data and check the most important ones.
if [ ! -f "$CFG_FILE" ]; then
	echo "Sorry. No configuration file called \"$CFG_FILE\" found. I need one to"
	echo "create an image for you."
	exit 1
fi

echo "Including configuration"
. $CFG_FILE

# Include the function set
if [ ! -f "$BASE_DIR/scripts/functions" ]; then
	echo "Seems that your config file contains an invalid BASE_DIR declaration: Can't"
	echo "include the functions file."
	exit 1
fi
echo "Including function set"
. $BASE_DIR/scripts/functions

echo "Including module set"
MODULE_DIR=$BASE_DIR/modules/$MODULE
. $MODULE_DIR/module.main


## Main Part -------------------------------------------------------------------
#
echo "Performing action. This can take a long long time."

# Cleanup
[ "X$CLEAN" != "X" ] && cleanup

# Create the base image
[ "X$CREATE" != "X" ] && create_image

# Strip the image
[ "X$STRIP" != "X" ] && strip_image

# Create tarred image
[ "X$TAR" != "X" ] && tar_image

# Create cramfs
[ "X$CRAMFS" != "X" ] && cramfs_image

echo "Completed."
exit 0

